pitchtools.PitchRange
=====================

.. abjad-lineage:: abjad.tools.pitchtools.PitchRange.PitchRange

.. autoclass:: abjad.tools.pitchtools.PitchRange.PitchRange

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.PitchRange.PitchRange.is_symbolic_pitch_range_string
      ~abjad.tools.pitchtools.PitchRange.PitchRange.one_line_named_pitch_repr
      ~abjad.tools.pitchtools.PitchRange.PitchRange.one_line_numbered_pitch_repr
      ~abjad.tools.pitchtools.PitchRange.PitchRange.pitch_range_name
      ~abjad.tools.pitchtools.PitchRange.PitchRange.pitch_range_name_markup
      ~abjad.tools.pitchtools.PitchRange.PitchRange.start_pitch
      ~abjad.tools.pitchtools.PitchRange.PitchRange.start_pitch_is_included_in_range
      ~abjad.tools.pitchtools.PitchRange.PitchRange.stop_pitch
      ~abjad.tools.pitchtools.PitchRange.PitchRange.stop_pitch_is_included_in_range
      ~abjad.tools.pitchtools.PitchRange.PitchRange.__contains__
      ~abjad.tools.pitchtools.PitchRange.PitchRange.__eq__
      ~abjad.tools.pitchtools.PitchRange.PitchRange.__format__
      ~abjad.tools.pitchtools.PitchRange.PitchRange.__ge__
      ~abjad.tools.pitchtools.PitchRange.PitchRange.__gt__
      ~abjad.tools.pitchtools.PitchRange.PitchRange.__illustrate__
      ~abjad.tools.pitchtools.PitchRange.PitchRange.__le__
      ~abjad.tools.pitchtools.PitchRange.PitchRange.__lt__
      ~abjad.tools.pitchtools.PitchRange.PitchRange.__ne__
      ~abjad.tools.pitchtools.PitchRange.PitchRange.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.one_line_named_pitch_repr
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.one_line_numbered_pitch_repr
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.pitch_range_name
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.pitch_range_name_markup
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.start_pitch
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.start_pitch_is_included_in_range
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.stop_pitch
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchRange.PitchRange.stop_pitch_is_included_in_range
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.is_symbolic_pitch_range_string
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.__illustrate__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchRange.PitchRange.__repr__
   :noindex:
